@@ -24,7 +24,8 @@ from .sheets import (
     Reader,
     SeriesReader,
     ColumnSeriesReader,
-    load_from_memory)
+    load_from_memory,
+    load_from_sql)
 from .utils import to_dict, to_array, to_records, dict_to_array, from_records
 from .formatters import (
     ColumnFormatter,
