@@ -9,20 +9,25 @@
 """
 from functools import partial
 from .csvbook import CSVBook, CSVWriter
+from .csvzipbook import CSVZipWriter, CSVZipBook
 from .._compact import is_string
 
 
 # A list of registered readers
 READERS = {
     "csv": CSVBook,
-    "tsv": partial(CSVBook, dialect="excel-tab")
+    "tsv": partial(CSVBook, dialect="excel-tab"),
+    "csvz": CSVZipBook,
+    "tsvz": partial(CSVZipBook, dialect="excel-tab")
 }
 
 
 # A list of registered writers
 WRITERS = {
     "csv": CSVWriter,
-    "tsv": partial(CSVWriter, dialect="excel-tab")
+    "tsv": partial(CSVWriter, dialect="excel-tab"),
+    "csvz": CSVZipWriter,
+    "tsvz": partial(CSVZipWriter, dialect="excel-tab")
 }
 
 def list_readers():
